from setuptools import setup

setup(name='professorerdo_first',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['professorerdo_first'],
      author = 'Fan Fan',
      author_email = 'mike.fan@foxmail.com',
    zip_safe=False)
